@@ -41,7 +41,10 @@ class SendGrid(object):
                 "get": "/api/newsletter/identity/get.json"},
             "subuser":{ #create new subuser
                 "add": "/apiv2/customer.add.json",
-                "list": "/apiv2/customer.profile.json"}
+                "list": "/apiv2/customer.profile.json"},
+            "sendip":{ #create new subuser
+                "add": "/apiv2/customer.sendip.json",
+                "get": "/apiv2/customer.ip.json"}
         }
 
     def build_params(self, d=None):
@@ -121,7 +124,7 @@ class SendGrid(object):
     def add_list(self, name):
         return self.call('lists', 'add', {"list": name})
 
-    def get_list(self, name):
+    def get_list(self, name=None):
         return self.call('lists', 'get', {"list": name} if name else {})
 
     def add_email_to(self, list_name, **fields):
@@ -169,6 +172,10 @@ class SendGrid(object):
     def list_subusers(self):
         return self.call('subuser', 'list', dict(task="get"))
 
+    def add_sendip(self, **fields):
+        '''Fields can be task, user, set, ip'''
+        return self.call('sendip', 'add', dict(task="get", **fields))
+
     def warm_up_from_csv(self,
                         csv_path,  # name, email csv string (no header)
                         newsletter_name,  # existing newsletter_name to be cloned
